def print_lol(the_list, indent = False, level = 0):
        for each_itme in the_list:
                if isinstance(each_itme, list):
                        print_lol(each_itme, indent, level + 1)
                else:
                        if indent:
                                for tap_stop in range(level):
                                        print("\t", end= ' ')
                                print(each_itme)                       



from distutils.core import setup

setup(
    name = 'maxwellzhou_nester',
    version = '1.3.0',
    py_modules = ['maxwellzhou_nester'],
    author = 'Maxwell',
    author_email = 'llasionzhou@gmail.com',
    url = 'http://www.headfirstlabs.com',
    description = 'A simple printer of nested lists',
    )
